@@ -3,7 +3,6 @@ import logging
 import signal
 import sys
 import time
-from dataclasses import dataclass
 from pathlib import Path
 
 from . import const
@@ -19,6 +18,8 @@ from .log import get_logger
 from .state import global_state as _state
 from .types import *
 
+Ping = namedtuple('Ping', 'trade_server terminal')
+
 
 class _ContextAwareBase:
     __state = _state
@@ -31,12 +32,6 @@ class _ContextAwareBase:
         return super().__new__(cls)
 
 
-@dataclass
-class Ping:
-    terminal: int
-    trade_server: int
-
-
 class connected:
     def __init__(self, *,
                  path: Union[str, Path] = None,
@@ -209,21 +204,11 @@ class connected:
     def logger(self) -> logging.Logger:
         return self._logger
 
-    #
     @logger.setter
     def logger(self, new_logger):
         self._logger = new_logger
         _state.logger = new_logger
 
-    # @property
-    # def debug_logging(self):
-    #     return self._debug_logging
-    #
-    # @debug_logging.setter
-    # def debug_logging(self, flag: bool):
-    #     _state.debug_logging = flag
-    #     self._debug_logging = flag
-
     @property
     def raise_on_errors(self) -> bool:
         return self._raise_on_errors
@@ -258,7 +243,8 @@ class connected:
         self._native_python_objects = flag
 
     def ping(self) -> Ping:
-        """Get ping in microseconds for the terminal and server.
+        """Get ping in microseconds for the terminal and trade_server.
+        Ping attrs = Ping.terminal and Ping.trade_server
 
         :return: dict with 'server' and 'terminal' ping
         """
